======
1.18.7
======

-------
General
-------

************
Enhancements
************

- Core & Internals: list_replicas needs to return dataset information for client_extract mode `#1677 <https://github.com/rucio/rucio/issues/1677>`_
- Core & Internals: Minor repository cleanup `#1841 <https://github.com/rucio/rucio/issues/1841>`_
- Documentation: Typos and other small fixes `#1853 <https://github.com/rucio/rucio/issues/1853>`_
- Probes & Alarms: Voms collector must change the emails according to the email defined in ldap  `#1656 <https://github.com/rucio/rucio/issues/1656>`_
- Probes & Alarms: Probe to automatically recover suspicious files that have multiple replicas `#1871 <https://github.com/rucio/rucio/issues/1871>`_
- Rebalancing: Several small BB8 optimisiations `#425 <https://github.com/rucio/rucio/issues/425>`_

****
Bugs
****

- Clients: import of builtins not Python 2.6 compatible in downloadclient `#1845 <https://github.com/rucio/rucio/issues/1845>`_
- Probes & Alarms: ‘expired’ and ‘obsolete’ counters are not correctly updated `#1849 <https://github.com/rucio/rucio/issues/1849>`_
- Traces: Suspicious file reporting broken in Kronos `#1870 <https://github.com/rucio/rucio/issues/1870>`_
- Traces: Protection against bad traces `#1882 <https://github.com/rucio/rucio/issues/1882>`_
- Transfers: Wrongly handled exception makes the poller crash `#1788 <https://github.com/rucio/rucio/issues/1788>`_
- Transfers: Conveyor submitter fts error message wrong `#1835 <https://github.com/rucio/rucio/issues/1835>`_


-------
Clients
-------

************
Enhancements
************

- Clients: Improve output of get-metadata, list-rse-attributes and stat  `#1842 <https://github.com/rucio/rucio/issues/1842>`_
- Clients: Last python3 fixes for clients `#1888 <https://github.com/rucio/rucio/issues/1888>`_
- Clients: Client migration to Python3 `#819 <https://github.com/rucio/rucio/issues/819>`_

-----
WebUI
-----

************
Enhancements
************

- WebUI: Add the possibility to remove suspicious files from the bad files summary plots `#1864 <https://github.com/rucio/rucio/issues/1864>`_
